emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] emacs-26 572e34b: Rename 'make-symbolic-link' argument NEW


From: Juanma Barranquero
Subject: [Emacs-diffs] emacs-26 572e34b: Rename 'make-symbolic-link' argument NEWNAME to LINKNAME
Date: Fri, 21 Jun 2019 15:43:39 -0400 (EDT)

branch: emacs-26
commit 572e34bb6fcbbbde2325b679fef64ee26e78ce8a
Author: Juanma Barranquero <address@hidden>
Commit: Juanma Barranquero <address@hidden>

    Rename 'make-symbolic-link' argument NEWNAME to LINKNAME
    
    * src/fileio.c (Fmake_symbolic_link): Fix docstring.
    * doc/lispref/files.texi (Changing Files): Doc fix.
---
 doc/lispref/files.texi |  8 ++++----
 src/fileio.c           | 10 +++++-----
 2 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/doc/lispref/files.texi b/doc/lispref/files.texi
index 380e054..ebe2fdd 100644
--- a/doc/lispref/files.texi
+++ b/doc/lispref/files.texi
@@ -1759,12 +1759,12 @@ default file permissions (see 
@code{set-default-file-modes} below), if
 SELinux context are not copied over in either case.
 @end deffn
 
-@deffn Command make-symbolic-link target newname &optional ok-if-already-exists
+@deffn Command make-symbolic-link target linkname &optional 
ok-if-already-exists
 @pindex ln
 @kindex file-already-exists
 This command makes a symbolic link to @var{target}, named
-@var{newname}.  This is like the shell command @samp{ln -s
-@var{target} @var{newname}}.  The @var{target} argument
+@var{linkname}.  This is like the shell command @samp{ln -s
+@var{target} @var{linkname}}.  The @var{target} argument
 is treated only as a string; it need not name an existing file.
 If @var{ok-if-already-exists} is an integer, indicating interactive
 use, then leading @samp{~} is expanded and leading @samp{/:} is
@@ -1774,7 +1774,7 @@ If @var{target} is a relative file name, the resulting 
symbolic link
 is interpreted relative to the directory containing the symbolic link.
 @xref{Relative File Names}.
 
-If both @var{target} and @var{newname} have remote file name syntax,
+If both @var{target} and @var{linkname} have remote file name syntax,
 and if both remote identifications are equal, the symbolic link points
 to the local file name part of @var{target}.
 
diff --git a/src/fileio.c b/src/fileio.c
index ba7cadd..47619c0 100644
--- a/src/fileio.c
+++ b/src/fileio.c
@@ -2474,13 +2474,13 @@ This is what happens in interactive use with M-x.  */)
 
 DEFUN ("make-symbolic-link", Fmake_symbolic_link, Smake_symbolic_link, 2, 3,
        "FMake symbolic link to file: \nGMake symbolic link to file %s: \np",
-       doc: /* Make a symbolic link to TARGET, named NEWNAME.
-If NEWNAME is a directory name, make a like-named symbolic link under
-NEWNAME.
+       doc: /* Make a symbolic link to TARGET, named LINKNAME.
+If LINKNAME is a directory name, make a like-named symbolic link under
+LINKNAME.
 
-Signal a `file-already-exists' error if a file NEWNAME already exists
+Signal a `file-already-exists' error if a file LINKNAME already exists
 unless optional third argument OK-IF-ALREADY-EXISTS is non-nil.
-An integer third arg means request confirmation if NEWNAME already
+An integer third arg means request confirmation if LINKNAME already
 exists, and expand leading "~" or strip leading "/:" in TARGET.
 This happens for interactive use with M-x.  */)
   (Lisp_Object target, Lisp_Object linkname, Lisp_Object ok_if_already_exists)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]